@@ -1020,12 +1020,21 @@ class StatusUpdateWebAppWorker(CommonTasksWebAppWorker):
                     os.remove(emdbLogPath)
                 #
                 emhu = EmHeaderUtils(siteId=self._siteId, verbose=self._verbose, log=self._lfh)
-                emhu.transEmd(filePath, emdFilePath, tags=headerFilters)
 
-                ok3c = emhu.transHeader(emdFilePath, emdbFilePath, emdbLogPath)
+                # Legacy code
+
+                mPath = filePath
+                emdfile = False
+                if hasattr(emhu, "transEmd"):
+                    emhu.transEmd(filePath, emdFilePath, tags=headerFilters)
+                    mPath = emdFilePath
+                    emdfile = True
+
+                ok3c = emhu.transHeader(mPath, emdbFilePath, emdbLogPath)
                 #
-                du.copyToDownload(emdFilePath)
-                aTagList.append(du.getAnchorTag())
+                if emdfile:
+                    du.copyToDownload(emdFilePath)
+                    aTagList.append(du.getAnchorTag())
                 if ok3c and os.access(emdbFilePath, os.R_OK):
                     du.copyToDownload(emdbFilePath)
                     aTagList.append(du.getAnchorTag())
@@ -1132,7 +1141,7 @@ class StatusUpdateWebAppWorker(CommonTasksWebAppWorker):
 
             pdbxArchivePath = pI.getModelPdbxFilePath(dataSetId=idCode, wfInstanceId=None, fileSource="archive", versionId="next", mileStone=None)
             if self._verbose:
-                self._lfh.write("+StatusUpdateWebAppWorker.__statusUpdateOtherOpeOp() model input path %s model archive output path %s\n" % (filePath, pdbxArchivePath))
+                self._lfh.write("+StatusUpdateWebAppWorker.__statusUpdateOtherOp() model input path %s model archive output path %s\n" % (filePath, pdbxArchivePath))
 
             # filePath is session directory
 
@@ -1147,6 +1156,7 @@ class StatusUpdateWebAppWorker(CommonTasksWebAppWorker):
             ok1 = False
             ok1a = False
             ok2 = False
+            ok3 = False
 
             if hasPdb:
                 ok1 = sU.wfLoad(idCode, annotatorInitials=newAnnotatorInitials, authRelCode=newPdbStatus)
@@ -1182,27 +1192,37 @@ class StatusUpdateWebAppWorker(CommonTasksWebAppWorker):
                 # Copy to archive
                 shutil.copyfile(filePath, pdbxArchivePath)
 
-                # Fetch again
-                du.fetchId(idCode, "model", formatType="pdbx")
-                aTagList.append(du.getAnchorTag())
-                rC.setHtmlLinkText('<span class="url-list">Download: %s</span>' % ",".join(aTagList))
-                rC.setStatus(statusMsg="Status updated")
+                ok3 = sU.dbLoad(filePath)
+                self._lfh.write("+StatusUpdateWebAppWorker._statusUpdateOtherOp() dbLoad completed %r\n" % ok3)
 
-                myD = {}
-                myD["authrelcode"] = newPdbStatus
-                myD["holdcoordinatesdate"] = newPdbHoldDate
-                myD["process_site"] = newProcessSite
-                myD["annotator_initials"] = newAnnotatorInitials
-                myD["em_depui_depositor_hold_instructions"] = newEmStatus
-                myD["em_map_hold_date"] = newEmHoldDate
+                if ok3:
+                    # Fetch again
+                    du.fetchId(idCode, "model", formatType="pdbx")
+                    aTagList.append(du.getAnchorTag())
+                    rC.setHtmlLinkText('<span class="url-list">Download: %s</span>' % ",".join(aTagList))
+                    rC.setStatus(statusMsg="Status updated")
 
-                for k, v in myD.items():
-                    rC.set(k, v)
-                self._saveSessionParameter(pvD=myD)
+                    myD = {}
+                    myD["authrelcode"] = newPdbStatus
+                    myD["holdcoordinatesdate"] = newPdbHoldDate
+                    myD["process_site"] = newProcessSite
+                    myD["annotator_initials"] = newAnnotatorInitials
+                    myD["em_depui_depositor_hold_instructions"] = newEmStatus
+                    myD["em_map_hold_date"] = newEmHoldDate
+
+                    for k, v in myD.items():
+                        rC.set(k, v)
+                    self._saveSessionParameter(pvD=myD)
+                else:
+                    rC.setError(errMsg="Update failed.")
 
             else:
                 rC.setError(errMsg="Update failed.")
 
+            status1 = killAllWF(idCode, "statMod")
+            if self._verbose:
+                self._lfh.write("+StatusUpdateWebAppWorker._statusCodeUpdateOp() killallwf returns %r\n" % status1)
+
         else:
             rC.setError(errMsg="Status update failed, data file cannot be accessed.")
             # do nothing
@@ -1460,13 +1480,21 @@ class StatusUpdateWebAppWorker(CommonTasksWebAppWorker):
                 headerFilters = []
 
                 emhu = EmHeaderUtils(siteId=self._siteId, verbose=self._verbose, log=self._lfh)
-                emhu.transEmd(filePath, emdFilePath, tags=headerFilters)
+
+                mPath = filePath
+                emdfile = False
+                if hasattr(emhu, "transEmd"):
+                    emhu.transEmd(filePath, emdFilePath, tags=headerFilters)
+                    mPath = emdFilePath
+                    emdfile = True
+
                 #
                 # Create XML file
-                ok3c = emhu.transHeader(emdFilePath, emdbFilePath, emdbLogPath)
+                ok3c = emhu.transHeader(mPath, emdbFilePath, emdbLogPath)
                 #
-                du.copyToDownload(emdFilePath)
-                aTagList.append(du.getAnchorTag())
+                if emdfile:
+                    du.copyToDownload(emdFilePath)
+                    aTagList.append(du.getAnchorTag())
 
                 ok5 = False
                 if ok3c and os.access(emdbFilePath, os.R_OK):
